@@ -66,7 +66,7 @@ class ProfileSyncer():
         self.process.wait()
         data = self.process.read()
         self.process.close()
-        return "No such file or directory (2)" not in data
+        return b"No such file or directory (2)" not in data
 
     def sync(self, source, target, *params):
         num = -1
